==> cscec5b-rmat-impl-3.0.1-20221025.085610-22-sources.jar: com/ejianc/business/rmat/bean/ExitApplyDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_apply_detail")
public class ExitApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private Long pId; // 退场申请单ID
    @TableField(value="refer_type")
    private Integer referType; // 参照类型(1在场周转材2材料库)
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 型号
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量/在租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_exit_num")
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    @TableField(value="real_exit_num")
    private BigDecimal realExitNum; // 申请退场数量(实物)
    @TableField(value="off_rent_date")
    private Date offRentDate; // 止租日
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="sign_row_type")
    private Integer signRowType; // 合同签订方式1-分类，2-材料

    

    public Long getPId() {
        return pId;
    }

    public void setPId(Long pId) {
        this.pId = pId;
    }
    public Integer getReferType() {
        return referType;
    }

    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public Date getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }
}

==> cscec5b-rmat-impl-3.0.1-20221122.102656-95-sources.jar: com/ejianc/business/rmat/bean/ExitApplyDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 退场申请单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_rmat_exit_apply_detail")
public class ExitApplyDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private Long pId; // 退场申请单ID
    @TableField(value="refer_type")
    private Integer referType; // 参照类型(1在场周转材2材料库)
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="spec")
    private String spec; // 型号
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位id
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位
    @TableField(value="unit_id")
    private String unitId; // 档案单位id
    @TableField(value="unit_name")
    private String unitName; // 档案单位
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位id
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位
    @TableField(value="num")
    private BigDecimal num; // 档案数量
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租数量/在租数量
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物数量
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="rent_exit_num")
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    @TableField(value="real_exit_num")
    private BigDecimal realExitNum; // 申请退场数量(实物)
    @TableField(value="off_rent_date")
    private Date offRentDate; // 止租日
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="sign_row_type")
    private Integer signRowType; // 合同签订方式1-分类，2-材料
    @TableField(value="is_true")
    private Integer isTrue;//是否能编辑  不等于空能编辑

    

    public Long getPId() {
        return pId;
    }

    public void setPId(Long pId) {
        this.pId = pId;
    }
    public Integer getReferType() {
        return referType;
    }

    public void setReferType(Integer referType) {
        this.referType = referType;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }
    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }
    public Date getOffRentDate() {
        return offRentDate;
    }

    public void setOffRentDate(Date offRentDate) {
        this.offRentDate = offRentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public Integer getIsTrue() {
        return isTrue;
    }

    public void setIsTrue(Integer isTrue) {
        this.isTrue = isTrue;
    }
}
